@@ -29,8 +29,8 @@ from django_testscenarios.ubertest import (
 )
 from django.contrib.auth.models import User
 from linaro_dashboard_bundle.errors import DocumentFormatError
-from linaro_json.schema import ValidationError
-from linaro_json.extensions import datetime_extension
+from json_schema_validator.errors import ValidationError
+from json_schema_validator.extensions import datetime_extension
 
 
 from dashboard_app.tests import fixtures
@@ -728,15 +728,20 @@ class BundleDeserializerAtomicityTestCase(TransactionTestCase):
 
     def test_error_trace(self):
         self.s_bundle.deserialize()
-        # The message depends on the database. This is a little ugly but it's
-        # better than not knowing what really happened and hiding other
-        # potential bugs that would otherwise be masked here.
+        # The message depends on the database -- even the version of the
+        # database.  This is a little ugly but it's better than not knowing
+        # what really happened and hiding other potential bugs that would
+        # otherwise be masked here.
+        error_message = self.s_bundle.deserialization_error.error_message
+        error_first_line = error_message.splitlines()[0].strip()
         self.assertIn(
-            self.s_bundle.deserialization_error.error_message, [
+            error_first_line,
+            [
                 'A test with UUID 1ab86b36-c23d-11df-a81b-002163936223 already exists',
                 'column analyzer_assigned_uuid is not unique',
                 u'duplicate key value violates unique constraint '
-                u'"dashboard_app_testrun_analyzer_assigned_uuid_key"\n'])
+                '"dashboard_app_testrun_analyzer_assigned_uuid_key"',
+                ])
 
     def test_deserialization_failure_does_not_leave_junk_behind(self):
         self.s_bundle.deserialize()
